@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (c) 2014-2020 Claudiu Popa <pcmanticore@gmail.com>
 # Copyright (c) 2014-2015 Brett Cannon <brett@python.org>
 # Copyright (c) 2015 Simu Toni <simutoni@gmail.com>
@@ -11,9 +10,9 @@
 # Copyright (c) 2016 Roy Williams <rwilliams@lyft.com>
 # Copyright (c) 2016 Łukasz Rogalski <rogalski.91@gmail.com>
 # Copyright (c) 2016 Erik <erik.eriksson@yahoo.com>
+# Copyright (c) 2017, 2020 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017-2018 Ville Skyttä <ville.skytta@iki.fi>
 # Copyright (c) 2017 Daniel Miller <millerdev@gmail.com>
-# Copyright (c) 2017 hippo91 <guillaume.peillex@gmail.com>
 # Copyright (c) 2017 ahirnish <ahirnish@gmail.com>
 # Copyright (c) 2018-2020 Anthony Sottile <asottile@umich.edu>
 # Copyright (c) 2018 sbagan <pnlbagan@gmail.com>
@@ -23,17 +22,20 @@
 # Copyright (c) 2018 Sushobhit <31987769+sushobhit27@users.noreply.github.com>
 # Copyright (c) 2018 Ashley Whetter <ashley@awhetter.co.uk>
 # Copyright (c) 2018 gaurikholkar <f2013002@goa.bits-pilani.ac.in>
+# Copyright (c) 2019-2021 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2019 Nick Drozd <nicholasdrozd@gmail.com>
 # Copyright (c) 2019 Hugues Bruant <hugues.bruant@affirm.com>
 # Copyright (c) 2019 Gabriel R Sezefredo <gabriel@sezefredo.com.br>
 # Copyright (c) 2019 Hugo van Kemenade <hugovk@users.noreply.github.com>
-# Copyright (c) 2019 Pierre Sassoulas <pierre.sassoulas@gmail.com>
 # Copyright (c) 2019 bluesheeptoken <louis.fruleux1@gmail.com>
+# Copyright (c) 2020 Peter Kolbus <peter.kolbus@gmail.com>
 # Copyright (c) 2020 谭九鼎 <109224573@qq.com>
 # Copyright (c) 2020 Federico Bond <federicobond@gmail.com>
 # Copyright (c) 2020 Athos Ribeiro <athoscr@fedoraproject.org>
+# Copyright (c) 2021 Tiago Honorato <tiagohonorato1@gmail.com>
+# Copyright (c) 2021 tiagohonorato <61059243+tiagohonorato@users.noreply.github.com>
 # Licensed under the GPL: https://www.gnu.org/licenses/old-licenses/gpl-2.0.html
-# For details: https://github.com/PyCQA/pylint/blob/master/COPYING
+# For details: https://github.com/PyCQA/pylint/blob/master/LICENSE
 
 """Check Python 2 code for Python 2/3 source-compatible issues."""
 import itertools
@@ -42,7 +44,6 @@ import tokenize
 from collections import namedtuple
 
 import astroid
-from astroid import bases
 
 from pylint import checkers, interfaces
 from pylint.checkers import utils
@@ -71,8 +72,8 @@ def _inferred_value_is_dict(value):
     return isinstance(value, astroid.Instance) and "dict" in value.basenames
 
 
-def _infer_if_relevant_attr(node, whitelist):
-    return node.expr.infer() if node.attrname in whitelist else []
+def _infer_if_relevant_attr(node, relevant_attrs):
+    return node.expr.infer() if node.attrname in relevant_attrs else []
 
 
 def _is_builtin(node):
@@ -96,6 +97,8 @@ _ACCEPTS_ITERATOR = {
     "min",
     "frozenset",
     "OrderedDict",
+    "zip",
+    "map",
 }
 ATTRIBUTES_ACCEPTS_ITERATOR = {"join", "from_iterable"}
 _BUILTIN_METHOD_ACCEPTS_ITERATOR = {
@@ -163,8 +166,7 @@ def _in_iterating_context(node):
 
 
 def _is_conditional_import(node):
-    """Checks if an import node is in the context of a conditional.
-    """
+    """Checks if an import node is in the context of a conditional."""
     parent = node.parent
     return isinstance(
         parent, (astroid.TryExcept, astroid.ExceptHandler, astroid.If, astroid.IfExp)
@@ -947,13 +949,15 @@ class Python3Checker(checkers.BaseChecker):
         self._branch_stack.append(Branch(node, self._is_py2_test(node)))
 
     def leave_if(self, node):
-        assert self._branch_stack.pop().node == node
+        new_node = self._branch_stack.pop().node
+        assert new_node == node
 
     def visit_ifexp(self, node):
         self._branch_stack.append(Branch(node, self._is_py2_test(node)))
 
     def leave_ifexp(self, node):
-        assert self._branch_stack.pop().node == node
+        new_node = self._branch_stack.pop()
+        assert new_node.node == node
 
     def visit_module(self, node):  # pylint: disable=unused-argument
         """Clear checker state after previous module."""
@@ -974,7 +978,9 @@ class Python3Checker(checkers.BaseChecker):
                 # classmethod 1 argument should cause a failure, if it is a
                 # staticmethod 0 arguments should cause a failure.
                 failing_arg_count = 1
-                if utils.decorated_with(node, [bases.BUILTINS + ".staticmethod"]):
+                if utils.decorated_with(
+                    node, [astroid.bases.BUILTINS + ".staticmethod"]
+                ):
                     failing_arg_count = 0
                 if len(node.args.args) == failing_arg_count:
                     self.add_message("next-method-defined", node=node)
@@ -1112,7 +1118,7 @@ class Python3Checker(checkers.BaseChecker):
             if not inferred:
                 return
 
-            builtins_list = "{}.list".format(bases.BUILTINS)
+            builtins_list = f"{astroid.bases.BUILTINS}.list"
             if isinstance(inferred, astroid.List) or inferred.qname() == builtins_list:
                 kwargs = node.keywords
 
@@ -1121,7 +1127,7 @@ class Python3Checker(checkers.BaseChecker):
             if not inferred:
                 return
 
-            builtins_sorted = "{}.sorted".format(bases.BUILTINS)
+            builtins_sorted = f"{astroid.bases.BUILTINS}.sorted"
             if inferred.qname() == builtins_sorted:
                 kwargs = node.keywords
 
@@ -1182,7 +1188,7 @@ class Python3Checker(checkers.BaseChecker):
                         and node.func.attrname in DICT_METHODS
                     ):
                         if not _in_iterating_context(node):
-                            checker = "dict-{}-not-iterating".format(node.func.attrname)
+                            checker = f"dict-{node.func.attrname}-not-iterating"
                             self.add_message(checker, node=node)
             except astroid.InferenceError:
                 pass
@@ -1233,7 +1239,7 @@ class Python3Checker(checkers.BaseChecker):
             if _is_builtin(found_node):
                 if node.func.name in ("filter", "map", "range", "zip"):
                     if not _in_iterating_context(node):
-                        checker = "{}-builtin-not-iterating".format(node.func.name)
+                        checker = f"{node.func.name}-builtin-not-iterating"
                         self.add_message(checker, node=node)
                 elif node.func.name == "open" and node.keywords:
                     kwargs = node.keywords
